@@ -50,6 +50,13 @@
 #define SQL_ATTR_REPLACE_QUOTED_LITERALS 2586
 #endif
 
+/* needed for backward compatibility (SQL_ATTR_ROWCOUNT_PREFETCH not defined prior to DB2 9.5.0.3) */
+#ifndef SQL_ATTR_ROWCOUNT_PREFETCH
+#define SQL_ATTR_ROWCOUNT_PREFETCH 2592
+#define SQL_ROWCOUNT_PREFETCH_OFF   0
+#define SQL_ROWCOUNT_PREFETCH_ON    1
+#endif
+
 #ifndef SQL_ATTR_USE_TRUSTED_CONTEXT
 #define SQL_ATTR_USE_TRUSTED_CONTEXT 2561
 #define SQL_ATTR_TRUSTED_CONTEXT_USERID 2562
